<?php

switch ($messaggio) {

case "Scegli la lingua":  			$messaggio = "V&auml;lj spr&aring;k"; break;
case "cambia la lingua":  			$messaggio = "&auml;ndra spr&aring;k"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Tabell med alla bokningar"; break;
case "Cambia la valuta":  			$messaggio = "&Auml;ndra valuta"; break;
case "Scegli le colonne da far comparire":  	$messaggio = "&Auml;ndra visade kolumner"; break;
case "n° di settimane":  			$messaggio = "antal veckor"; break;
case "n° di giorni":  				$messaggio = "antal dagar"; break;
case "caparra":  				$messaggio = "deposition"; break;
case "pagato":  				$messaggio = "betald"; break;
case "resto da pagare":  			$messaggio = "kvar att betala"; break;
case "n° di persone":  				$messaggio = "antal personer"; break;
case "commento":  				$messaggio = "kommentar"; break;
case "costo aggiuntivo unico":  		$messaggio = "enkel extrakostnad"; break;
case "abbreviazione":  				$messaggio = "f&ouml;rkortning"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "veckolig extrakostnad"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daglig extrakostnad"; break;
case "cambia le colonne":  			$messaggio = "&auml;ndra kolumnerna"; break;
case "Tabelle dei mesi":  			$messaggio = "M&aring;nadstabeller"; break;
case "Numero di tabelle del 2° tipo":  		$messaggio = "Antal andra sortens tabeller"; break;
case "cambia":  				$messaggio = "&auml;ndra"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case "a":  					$messaggio = "till"; break;
case "La lingua è stata cambiata":  		$messaggio = "Spr&aring;ket har &auml;ndrats"; break;
case "La valuta è stata cambiata":  		$messaggio = "Valutan har &auml;ndrats"; break;
case "Le colonne sono state cambiate":  	$messaggio = "Kolumnerna har &auml;ndrats"; break;
case "Il numero di tabelle è stato cambiato":  	$messaggio = "Antalet tabeller har &auml;ndrats"; break;
case "Documenti":  				$messaggio = "Dokument"; break;
case "documento":  				$messaggio = "dokument"; break;
case "cambia i nomi dei documenti":  		$messaggio = "&auml;ndra dokumentnamn"; break;
case "I nomi dei documenti sono stati cambiati":	$messaggio = "Dokumentnamn har &auml;ndrats"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Pengavisningsformat"; break;
case "cambia formato":  			$messaggio = "&auml;ndra format"; break;
case "Il formato di visualizzazione dei soldi è stato cambiato":	$messaggio = "Pengavisningsformat har &auml;ndrats"; break;
case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "Le date dei menù a tendina sono state cambiate":	$messaggio = "Datumen f&ouml;r drop-down-menyer har &auml;ndrats"; break;
case "Scegli le date":  			$messaggio = "V&auml;lj datum"; break;
case "nei menù a tendina":  			$messaggio = "i drop-down-menyer"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "Tronca i cognomi nelle tabelle dopo ":	$messaggio = "Trunkera efternamn i tabellerna efter "; break;
case "caratteri per colonna":  			$messaggio = "bokst&auml;ver per kolumn"; break;
case "La lunghezza dei cognomi nelle tabelle dei mesi è stata cambiata":	$messaggio = "Efternamnsl&auml;ngd i m&aring;nadstabellen har &auml;ndrats"; break;
case "Cambia il numero delle tariffe":  	$messaggio = "&Auml;ndra antalet priser"; break;
case "per l'anno":  				$messaggio = "f&ouml;r &aring;r"; break;
case "Il numero delle tariffe è stato cambiato":	$messaggio = "Antalet priser har &auml;ndrats"; break;
case "Il numero di tariffe è sbagliato":  	$messaggio = "Antalet priser &auml;r felaktigt"; break;
case "Sistema di backup":  			$messaggio = "Backupsystem"; break;
case "Il numero delle righe è sbagliato":  	$messaggio = "Antalet rader &auml;r felaktigt"; break;
case "Cambia il numero delle righe":  		$messaggio = "&Auml;ndra antalet rader"; break;
case "Il numero delle righe della tabella con tutte le prenotazioni è stato cambiato":	$messaggio = "Antalet rader i tabellen med alla bokningar har &auml;ndrats"; break;
case "Il numero delle righe della tabella con la storia delle entrate e delle uscite è stato cambiato":	$messaggio = "Antalet rader i betalningshistoriktabellen har &auml;ndrats"; break;
case "Tabella con la storia delle entate e uscite":	$messaggio = "Betalningshistoriktabell"; break;
case "Il formato di visualizzazione delle date è stato cambiato":	$messaggio = "Datumvisningsformat har &auml;ndrats"; break;
case "Formato di visualizzazione delle date":	$messaggio = "Datumvisningsformat"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Tabell med alla kunder"; break;
case "Il numero delle righe della tabella con tutti i clienti è stato cambiato":	$messaggio = "Antalet rader i kundtabellen har &auml;ndrats"; break;
case "Si deve sceliere qualche dato da inserire nella colonna gruppo":	$messaggio = "Du m&aring;ste v&auml;lja n&aring;gon data att l&auml;gga till i gruppkolumnen"; break;
case "Si deve inserire il nome della colonna gruppo":	$messaggio = "Du m&aring;ste ange namnet p&aring; gruppkolumnen"; break;
case "La colonna gruppo è stata aggiunta":  	$messaggio = "Gruppkolumnen har lagts till"; break;
case "Aggiungi una colonna gruppo":  		$messaggio = "L&auml;gg till en gruppkolumn"; break;
case "Aggiungi colonna gruppo":  		$messaggio = "L&auml;gg till gruppkolumn"; break;
case "chiamata":  				$messaggio = "kallad"; break;
case "con":  					$messaggio = "med"; break;
case "colonna gruppo":  			$messaggio = "gruppkolumn"; break;
case "spazio":  				$messaggio = "mellanrum"; break;
case "trattino":  				$messaggio = "bindestreck"; break;
case "a capo":  				$messaggio = "ny rad"; break;
case " Do":  					$messaggio = " s&ouml;"; break;
case " Lu":  					$messaggio = " m&aring;"; break;
case " Ma":  					$messaggio = " ti"; break;
case " Me":  					$messaggio = " on"; break;
case " Gi":  					$messaggio = " to"; break;
case " Ve":  					$messaggio = " fr"; break;
case " Sa":  					$messaggio = " l&ouml;"; break;
case "Gen":  					$messaggio = "jan"; break;
case "Feb":  					$messaggio = "feb"; break;
case "Mar":  					$messaggio = "mar"; break;
case "Apr":  					$messaggio = "apr"; break;
case "Mag":  					$messaggio = "maj"; break;
case "Giu":  					$messaggio = "jun"; break;
case "Lug":  					$messaggio = "jul"; break;
case "Ago":  					$messaggio = "aug"; break;
case "Set":  					$messaggio = "sep"; break;
case "Ott":  					$messaggio = "okt"; break;
case "Nov":  					$messaggio = "nov"; break;
case "Dic":  					$messaggio = "dec"; break;
case "nome della tariffa":  			$messaggio = "prisnamn"; break;
case "data di inserimento":  			$messaggio = "infogningsdatum"; break;
case "tariffa completa":  			$messaggio = "komplett pris"; break;
case "Gestione utenti":  			$messaggio = "Anv&auml;ndaradministration"; break;
case "Personalizzazioni dell'utente":  		$messaggio = "Anpassningar f&ouml;r anv&auml;ndaren"; break;
case "Cambia":  				$messaggio = "&Auml;ndra"; break;
case "quelle di":  				$messaggio = "f&ouml;r"; break;
case "Importa i nomi dei documenti":  		$messaggio = "Importera dokumentnamn"; break;
case "Importa":  				$messaggio = "Importera"; break;
case "dell'utente":  				$messaggio = "f&ouml;r anv&auml;ndare"; break;
case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "Varaktigheten i minuter f&ouml;r sessioner och transaktioner har &auml;ndrats"; break;
case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "Antalet timmar i f&ouml;rv&auml;g innan bokningens b&ouml;rjan har &auml;ndrats"; break;
case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":	$messaggio = "Antalet minuter efter vilka sessionen g&aring;r ut uppdaterade inte sessioner och transaktioner"; break;
case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Antalet timmar efter vilka bokningens antas b&ouml;rja"; break;
case "utente":  				$messaggio = "anv&auml;ndare"; break;
case "Interconnessioni":  			$messaggio = "Samk&ouml;rning"; break;
case "Assegnazione automatica disattivata":  	$messaggio = "Automatisk tilldelning avaktiverad"; break;
case "Assegnazione automatica attivata":  	$messaggio = "Automatisk tilldelning aktiverad"; break;
case "Attiva":  				$messaggio = "Aktivera"; break;
case "Disattiva":  				$messaggio = "Avaktivera"; break;
case "Scegli il tema grafico":  		$messaggio = "V&auml;lj grafiskt tema"; break;
case "Il tema grafico è stato cambiato":  	$messaggio = "Grafiskt tema har &auml;ndrats"; break;
case "Registrazione degli orari di entrata ed uscita attivata":	$messaggio = "Registrering av in- och utcheckning aktiverad"; break;
case "Registrazione degli orari di entrata ed uscita disattivata":	$messaggio = "Registrering av in- och utcheckning avaktiverad"; break;
case "Le ore di differenza con l'orario del server sono state cambiate":	$messaggio = "Timskillnad fr&aring;n servertid har &auml;ndrats"; break;
case "Ore di differenza con l'orario del server": 	$messaggio = "Timskillnad fr&aring;n servertid"; break;
case "ora attuale":  				$messaggio = "nuvarande timme"; break;
case "numero":  				$messaggio = "nummer"; break;
case "cognome cliente":  			$messaggio = "kundefternamn"; break;
case "data iniziale":  				$messaggio = "startdatum"; break;
case "data finale":  				$messaggio = "slutdatum"; break;
case "Le colonne necessarie sono state cambiate":	$messaggio = "Beh&ouml;vda kolumner har &auml;ndrats"; break;
case "Non mostrare prenotazioni che non hanno almeno una di queste colonne necessarie (non selezionarene per mostrare tutte)":	$messaggio = "Visa inte bokningar som inte har minst en av dom beh&ouml;vda kolumnerna (v&auml;lj inga f&ouml;r att visa alla)"; break;
case "cambia le colonne necessarie":  		$messaggio = "&auml;ndra beh&ouml;vda kolumner"; break;
case "Metodo di pagamento eliminato":  		$messaggio = "Betalningsmetod borttagen"; break;
case "Nuovo metodo di pagamento aggiunto":  	$messaggio = "Ny betalningsmetod tillagd"; break;
case "Metodi di pagamento":  			$messaggio = "Betalningsmetoder"; break;
case "elimina":  				$messaggio = "ta bort"; break;
case "aggiungi":  				$messaggio = "l&auml;gg till"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "V&auml;gledande tillg&auml;nglighets&ouml;versikt"; break;
case "non mostrare":  				$messaggio = "visa inte"; break;
case "Il modo di visualizzazione del quadro di disponibilità è stato cambiato":	$messaggio = "Visningsl&auml;get f&ouml;r tillg&auml;nglighets&ouml;versikt har &auml;ndrats"; break;
case "Controllo disponibilità":  		$messaggio = "Tillg&auml;nglighetskontroll"; break;
case "settimane di intervallo":  		$messaggio = "veckor p&aring; intervallet"; break;
case "giorni di intervallo":  			$messaggio = "dagar p&aring; intervallet"; break;
case "Giorno di inizio/fine settimana cambiato":	$messaggio = "Begynnelse-/slutdag p&aring; veckan &auml;ndrad"; break;
case "Giorno di inizio/fine settimana nelle tabelle":	$messaggio = "Begynnelse-/slutdag p&aring; veckan i tabeller"; break;
case "Anno":  					$messaggio = "&Aring;r"; break;
case "Creazione automatica del nuovo anno disattivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Automatiskt skapande av nytt &aring;r avaktiverat (importerar data fr&aring;n tidigare &aring;r vid den f&ouml;rsta inloggningen av n&aring;gon anv&auml;ndare)"; break;
case "Creazione automatica del nuovo anno attivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Automatiskt skapande av nytt &aring;r aktiverat (importerar data fr&aring;n tidigare &aring;r vid den f&ouml;rsta inloggningen av n&aring;gon anv&auml;ndare)"; break;
case "Creazione automatica nuovo anno disattivata":	$messaggio = "Automatiskt skapande av nytt &aring;r avaktiverat"; break;
case "Creazione automatica nuovo anno attivata":	$messaggio = "Automatiskt skapande av nytt &aring;r aktiverat"; break;
case "Sostituisci la parola":  			$messaggio = "Ers&auml;tt ordet"; break;
case "Parole da sostituire":  			$messaggio = "Ord att ers&auml;tta"; break;
case "La parola da sostituire è stata aggiunta":	$messaggio = "Ordet att ers&auml;tta har lagts till"; break;
case "La parola da sostituire è stata eliminata":	$messaggio = "Ordet att ers&auml;tta har &auml;ndrats"; break;
case "modifica il documento":  			$messaggio = "&auml;ndra dokument"; break;
case "Aggiungi ai documenti":  			$messaggio = "L&auml;gg till dokument"; break;
case "variabili personalizzate":  		$messaggio = "valfria variabler"; break;
case "Cambia il numero dei documenti":  	$messaggio = "&Auml;ndra antalet dokument"; break;
case "Il numero di documenti è stato cambiato":	$messaggio = "Antalet dokument har &auml;ndrats"; break;
case "Il numero di documenti è sbagliato":  	$messaggio = "Antalet dokument &auml;r felaktigt"; break;
case "Indirizzo email":  			$messaggio = "E-postadress"; break;
case "Mascherare la provenienza delle email sull'envelope":	$messaggio = "Maskera s&auml;ndaren f&ouml;r e-postkuvertet"; break;
case "Il mascheramento della provenienza delle email è stato cambiato":	$messaggio = "Maskerandet av e-postavs&auml;ndare har &auml;ndrats"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "Jag har inte skrivr&auml;ttigheter f&ouml;r mappen"; break;
case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "Den angivna mappen <div style=\"display: inline; color: red;\">finns inte</div>"; break;
case "Selezionare in modo predefinito":  	$messaggio = "V&auml;lj som standard"; break;
case "tutte le prenotazioni":  			$messaggio = "alla bokningar"; break;
case "prenotazioni del periodo corrente":  	$messaggio = "bokningar under nuvarande period"; break;
case "La selezione predefinita delle prenotazioni nella tabella con tutte le prenotazioni è stata cambiata":	$messaggio = "Standardvalet f&ouml;r bokningar i bokningstabellen har &auml;ndrats"; break;
case "Numero di righe dopo cui ripetere la riga delle date":	$messaggio = "Antalet rader efter vilka datumraden ska visas p&aring; nytt"; break;
case "Il numero  di righe dopo cui ripetere la riga delle date è stato cambiato":	$messaggio = "Antalet rader efter vilka datumraden ska visas p&aring; nytt har &auml;ndrats"; break;
case "orario entrata stimato":  		$messaggio = "uppskattad incheckningstid"; break;
case "Mostrare i giorni nella riga delle date?":	$messaggio = "Visa dagarna i datumraden?"; break;
case "I giorni da mostrare nella tabella dei mesi sono stati cambiati":	$messaggio = "Dagarna som ska visas i datumraden har &auml;ndrats"; break;
case "Nazioni":  				$messaggio = "L&auml;nder"; break;
case "Elimina tutte":  				$messaggio = "Ta bort alla"; break;
case "Ripristina predefinite":  		$messaggio = "&Aring;terst&auml;tt standardv&auml;rden"; break;
case "Importa le nazioni":  			$messaggio = "Importera l&auml;nder"; break;
case "Regioni/provincie":  			$messaggio = "Regioner"; break;
case "Importa le regioni/provincie":  		$messaggio = "Importera regioner"; break;
case "Nazione cancellata":  			$messaggio = "Land borttaget"; break;
case "Regione/provincia cancellata":  		$messaggio = "Region borttagen"; break;
case "Nuova nazione aggiunta":  		$messaggio = "Nytt land tillagt"; break;
case "Nazioni predefinite ripristinate":  	$messaggio = "Standardl&auml;nder &aring;terst&auml;llda"; break;
case "Nazioni cancellate":  			$messaggio = "L&auml;nder borttagna"; break;
case "Nazioni importate":  			$messaggio = "L&auml;nder importerade"; break;
case "Nuova regione/provincia aggiunta":  	$messaggio = "Ny region tillagd"; break;
case "Regioni/provincie predefinite ripristinate":	$messaggio = "Standardregioner &aring;terst&auml;llda"; break;
case "Regioni/provincie cancellate":  		$messaggio = "Regioner borttagna"; break;
case "Regioni/provincie importate":  		$messaggio = "Regioner importerade"; break;
case "Parentele":  				$messaggio = "Sl&auml;ktskap"; break;
case "Importa le parentele":  			$messaggio = "Importera sl&auml;ktskap"; break;
case "Parentela cancellata":  			$messaggio = "Sl&auml;ktskap borttagen"; break;
case "Nuova parentela aggiunta":  		$messaggio = "Ny sl&auml;ktskap tillagd"; break;
case "Parentele predefinite ripristinate":  	$messaggio = "Standardsl&auml;ktskap &aring;terst&auml;lld"; break;
case "Parentele cancellate":  			$messaggio = "Sl&auml;ktskap borttagen"; break;
case "Parentele importate":  			$messaggio = "Sl&auml;ktskap importerad"; break;
case "origine":  				$messaggio = "ursprung"; break;
case "Origini delle prenotazioni":  		$messaggio = "Bokningsursprung"; break;
case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "Nytt bokningsursprung tillagt"; break;
case "Origine delle prenotazioni eliminata":  	$messaggio = "Bokningsursprung borttaget"; break;
case "Nome combinazione":  			$messaggio = "Kombinationsnamn"; break;
case "prenotazioni correnti e future":  	$messaggio = "nuvarande och framtida bokningar"; break;
case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Anpassningar f&ouml;r <b>alla anv&auml;ndare</b>"; break;
case "tutti gli utenti":  			$messaggio = "alla anv&auml;ndare"; break;
case "Personalizzazioni del gruppo":  		$messaggio = "Anpassningar f&ouml;r gruppen"; break;
case "gruppo":  				$messaggio = "grupp"; break;
case "Vedi i log":  				$messaggio = "Visa logg"; break;
case "Log delle query di modifica effettuate dagli utenti negli ultimi":	$messaggio = "Logg f&ouml;r &auml;ndringsf&ouml;rfr&aring;gningar gjorda av anv&auml;ndare i det f&ouml;rflutna"; break;
case "giorni":  				$messaggio = "dagar"; break;
case "Utente":  				$messaggio = "Anv&auml;ndare"; break;
case "Data":  					$messaggio = "Datum"; break;
case "Query":  					$messaggio = "F&ouml;rfr&aring;gan"; break;
case "Cancella tutti i log":  			$messaggio = "Ta bort alla loggar"; break;
case "Log delle query di modifica degli utenti normali disattivato":	$messaggio = "Logg f&ouml;r &auml;ndringsf&ouml;rfr&aring;gningar fr&aring;n normalanv&auml;ndare avaktiverad"; break;
case "Log delle query di modifica degli utenti normali attivato":	$messaggio = "Logg f&ouml;r &auml;ndringsf&ouml;rfr&aring;gningar fr&aring;n normalanv&auml;ndare aktiverad"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Anpassa tillg&auml;nglighet till anl&auml;ndandedatum?"; break;
case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "Anpassning av datum till tillg&auml;nglighet i m&aring;nadstabellen har &auml;ndrats"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Anpassning av tillg&auml;nglighet till anl&auml;ndandedatum kan &aring;stadkomma f&ouml;rvirring och misstag ang&aring;ende avresedatum, &auml;r du s&auml;ker p&aring; att du vill forts&auml;tta?"; break;
case "Documenti di identità":  			$messaggio = "Identitetsdokument"; break;
case "Tipo di documento di identità eliminato":	$messaggio = "Typ av identitetsdokument borttagen"; break;
case "Nuovo tipo di documento di identità aggiunto":	$messaggio = "Ny typ av identitetsdokument tillagd"; break;
case "Tipi di documento di identità predefiniti ripristinati":	$messaggio = "Standardtyper f&ouml;r identitetsdokument &aring;terst&auml;llda"; break;
case "Tipi di documento di identità cancellati":	$messaggio = "Typer av identitetsdokument borttagna"; break;
case "Tipi di documento di identità importati":	$messaggio = "Typer av identitetsdokument importerade"; break;
case "Importa i documenti di identità":  	$messaggio = "Importera identitetsdokument"; break;
case "codice":  				$messaggio = "kod"; break;
case "Nuova nazione":  				$messaggio = "Nytt land"; break;
case "Nuova regione/provincia":  		$messaggio = "Ny region"; break;
case "Nuovo documento d'identità":  		$messaggio = "Nytt identitetsdokument"; break;
case "Nuova parentela":  			$messaggio = "Nytt sl&auml;ktskap"; break;
case "Elimina tutti":  				$messaggio = "Ta bort alla"; break;
case "Ripristina predefiniti":  		$messaggio = "&Aring;terst&auml;ll standardv&auml;rden"; break;
case "Città":  					$messaggio = "St&auml;der"; break;
case "Nuova città":  				$messaggio = "Ny stad"; break;
case "Importa le città":  			$messaggio = "Importera st&auml;der"; break;
case "Città cancellata":  			$messaggio = "Stad borttagen"; break;
case "Nuova città aggiunta":  			$messaggio = "Ny stad tillagd"; break;
case "Città predefinite ripristinate":  	$messaggio = "Standardst&auml;der &aring;terst&auml;llda"; break;
case "Città cancellate":  			$messaggio = "St&auml;der borttagna"; break;
case "Città importate":  			$messaggio = "St&auml;der importerade"; break;
case "nella regione/provincia di":  		$messaggio = "i regionen"; break;
case "nella nazione":  				$messaggio = "i landet"; break;
case "Titoli dei clienti":  			$messaggio = "Kundtitlar"; break;
case "sesso":  					$messaggio = "k&ouml;n"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "k"; break;
case "Titolo dei clienti eliminato":  		$messaggio = "Kundtitlar borttagna"; break;
case "Nuovo titolo dei clienti aggiunto":  	$messaggio = "Ny kundtitel tillagd"; break;
case "I dati della struttura sono stati cambiati":	$messaggio = "Structure data have been changed"; break;
case "Dati della struttura":  			$messaggio = "Structure data"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Modifica i dati della struttura":  	$messaggio = "Modify structure data"; break;
case "ex":  					$messaggio = "ex"; break;
case "il":  					$messaggio = "the"; break;
case "2°":  					$messaggio = "2nd"; break;
case "3°":  					$messaggio = "3rd"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Configura e personalizza HotelDruid":	$messaggio = "Configure and customize HotelDruid"; break;
case "separatore":  				$messaggio = "separator"; break;
case "Pagine per il sito web":  		$messaggio = "Website pages"; break;
case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Directories where website pages are created"; break;
case "percorsi separati da virgole relativi":	$messaggio = "comma separated paths relative"; break;
case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "to the HotelDruid directory, if they don't begin with /"; break;
case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "The directories where website pages are created have been changed"; break;
case "Log delle query di modifica generate":	$messaggio = "Log of modification queries made"; break;
case "da tutti gli utenti":  			$messaggio = "by all users"; break;
case "dall'utente":  				$messaggio = "by user"; break;
case "dal gruppo":  				$messaggio = "by group"; break;
case "attivato":				$messaggio = "enabled"; break;
case "disattivato":				$messaggio = "disabled"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero stelle":  				$messaggio = "Stars number"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "Comune":  				$messaggio = "City"; break;
case "Indirizzo":  				$messaggio = "Address"; break;
case "CAP":  					$messaggio = "Postal code"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Clicca su un documento per modificarlo":	$messaggio = "Click on a document to modify it"; break;
case "Cambia l'ordine dei documenti":  		$messaggio = "Change documents order"; break;
case "Applica i cambiamenti":  			$messaggio = "Apply changes"; break;
case "Documento":  				$messaggio = "Document"; break;
case "L'ordine dei documenti è stato cambiato":	$messaggio = "Documents order has been changed"; break;
case "Sito web":  				$messaggio = "Website"; break;
case "Nome contatto":  				$messaggio = "Contact name"; break;
case "l'ordine delle tariffe è stato cambiato":	$messaggio = "rates order has been changed"; break;
case "cambia l'ordine delle tariffe":  		$messaggio = "change rates order"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "valore predefinito a cui arrotondare le percentuali dei prezzi":	$messaggio = "default rounding value for percentages of prices"; break;
case "è stato cambiato":  			$messaggio = "has been changed"; break;
case "password per la visualizzazione dei dati delle carte di credito":	$messaggio = "password to view credit cards data"; break;
case "attivata":  				$messaggio = "enabled"; break;
case "disattivata":  				$messaggio = "disabled"; break;
case "cambia la password":  			$messaggio = "change password"; break;
case "<b>Attenzione</b>: se si perde questa password non sarà più possibile leggere i dati delle carte di credito inserite":	$messaggio = "<b>Warning</b>: if you lose this password you won't be able to read inserted credit cards data anymore"; break;
case "nuova password":  			$messaggio = "new password"; break;
case "ripetere password":  			$messaggio = "repeat password"; break;
case "attiva la password":  			$messaggio = "activate password"; break;
case "le password inserite non coincidono":  	$messaggio = "inserted passwords do not coincide"; break;
case "errore nelle funzioni ssl":  		$messaggio = "error in ssl functions"; break;
case "<b class=\"colred\">Attenzione</b>: tutti i dati delle carte di credito verranno cancellati":	$messaggio = "<b class=\"colred\">Warning</b>: all credit cards data will be deleted"; break;
case "continua":  				$messaggio = "continue"; break;
case "vecchia password":  			$messaggio = "old password"; break;
case "cambiata":  				$messaggio = "changed"; break;
case "piano":  					$messaggio = "floor"; break;
case "casa":  					$messaggio = "house"; break;
case "2° codice":  				$messaggio = "2nd code"; break;
case "3° codice":  				$messaggio = "3rd code"; break;
case "Tabella con i documenti salvati":  	$messaggio = "Table with saved documents"; break;
case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "The number of rows of the table with saved documents has been changed"; break;
case "valore a cui arrotondare le percentuali delle tasse":	$messaggio = "rounding value for percentages of taxes"; break;
case "commissioni":  				$messaggio = "commissions"; break;
case "resto commissioni":  			$messaggio = "commissions rest"; break;
case "documenti salvati":  			$messaggio = "saved documents"; break;
case "Scegli le righe aggiuntive da mostrare":	$messaggio = "Choose extra rows to be shown"; break;
case "tasse":  					$messaggio = "taxes"; break;
case "trasferito in cassa":  			$messaggio = "transferred in cash box"; break;
case "cambia le righe":  			$messaggio = "change rows"; break;
case "Le righe aggiuntive sono state cambiate":	$messaggio = "Extra rows have been changed"; break;
case "totale":  				$messaggio = "total"; break;
case "soldi prenotazioni cancellate":  		$messaggio = "deleted reservations money"; break;
case "cognome ospite se differente":  		$messaggio = "guest surname if different"; break;
case "Ragione sociale":  			$messaggio = "Company name"; break;
case "URL del logo":  				$messaggio = "Logo URL"; break;
case "Nome delle unità da affittare":  		$messaggio = "Name of rental units"; break;
case "nome personalizzato":  			$messaggio = "custom name"; break;
case "singolare":  				$messaggio = "singular"; break;
case "plurale":  				$messaggio = "plural"; break;
case "genere":  				$messaggio = "gender"; break;
case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "The name of the rental unit has been changed"; break;
case "Tabelle con le casse":  			$messaggio = "Cashboxes tables"; break;
case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "The number of rows of the tables with the cashboxes has been changed"; break;
case "Elimina il documento":  			$messaggio = "Delete document"; break;
case "Sei sicuro di voler eliminare il documento":	$messaggio = "Are you sure you want to delete document"; break;
case "Il documento è stato eliminato":	$messaggio = "The document has been deleted"; break;
case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Fields to be considered when searching clients"; break;
case "cognome":  				$messaggio = "surname"; break;
case "email":  					$messaggio = "email"; break;
case "nome":  					$messaggio = "name"; break;
case "telefono":  				$messaggio = "telephone"; break;
case "città":  					$messaggio = "city"; break;
case "indirizzo":  				$messaggio = "address"; break;
case "codice postale":  			$messaggio = "postal code"; break;
case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "The fields to be considered when searching clients have been changed"; break;
case "Nome delle unità singole":  		$messaggio = "Name of single units"; break;
case "Tabella dei messaggi":  			$messaggio = "Messages table"; break;
case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "The number of rows of the messages table has been changed"; break;
case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Download emails for availability enquiries from mail server"; break;
case "per es.":  				$messaggio = "e.g."; break;
case "Protocollo":  				$messaggio = "Protocol"; break;
case "Porta":  					$messaggio = "Port"; break;
case "default":  				$messaggio = "default"; break;
case "persoalizzata":  				$messaggio = "custom"; break;
case "Nome utente":  				$messaggio = "Username"; break;
case "Password":  				$messaggio = "Password"; break;
case "lasciare vuota per chiedere ogni volta":	$messaggio = "leave empty to ask each time"; break;
case "Identificazione messaggi di richiesta":	$messaggio = "Enquiry messages identification"; break;
case "Messaggio iniziale":  			$messaggio = "First post"; break;
case "Qualsiasi messaggio":  			$messaggio = "Any post"; break;
case "da":  					$messaggio = "from"; break;
case "con oggetto contenete":  			$messaggio = "with subject containing"; break;
case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "The data to download emails are wrong or incomplete"; break;
case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "The download of emails for availability enquiries from mail server has been changed"; break;
case "Colori delle prenotazioni":  		$messaggio = "Reservations colors"; break;
case "Tutto pagato":  				$messaggio = "All paid"; break;
case "Caparra pagata":  			$messaggio = "Deposit paid"; break;
case "Confermate":  				$messaggio = "Confirmed"; break;
case "Non confermate":  			$messaggio = "Not confirmed"; break;
case "I colori sono sbagliati":  		$messaggio = "Colors are wrong"; break;
case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Reservations colors have been changed"; break;
case "Campi personalizzati dei clienti":  	$messaggio = "Custom fields for clients"; break;
case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "New custom field for clients added"; break;
case "Campo personalizzato dei clienti eliminato":	$messaggio = "Custom field for clients deleted"; break;
case "tipo":  					$messaggio = "type"; break;
case "booleano":  				$messaggio = "boolean"; break;
case "testo":  					$messaggio = "text"; break;
case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "The custom field contains not allowed characters"; break;
case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Manage the CVC codes from credit cards too"; break;
case "Esonero di responsabilità":  		$messaggio = "Disclaimer"; break;
case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "the CVC codes will be managed under your own responsibility, being aware that PCI security standards forbid their storage"; break;
case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "Accepting this clause confirms that the developers of this software are free from all responsibilities regarding the security of these data"; break;
case "Accetto":  				$messaggio = "I Accept"; break;
case "Declino":  				$messaggio = "I Decline"; break;
case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "mensile":  				$messaggio = "montly"; break;
case "tabella":  				$messaggio = "table"; break;
case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
case "alfabetico":  				$messaggio = "alphabetically"; break;
case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
case "La tariffa":  				$messaggio = "Rate"; break;
case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
case "diversa dalle ultime":  			$messaggio = "different from last"; break;
case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Conditions"; break;
case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>